import { RouteRecordRaw } from 'vue-router';

export const dynamicRoutes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: '/',
        component: () => import('/@/layout/index.vue'),
        redirect: '/home',
        meta: {
            isKeepAlive: false
        },
        children: [
            {
                path: '/home',
                name: 'home',
                component: () => import('/@/views/newHome/index.vue'),
                meta: {
                    title: '首页',
                    isLink: '',
                    isHide: false,
                    isKeepAlive: true,
                    isAffix: true,
                    isIframe: false,
                    roles: ['admin', 'common'],
                    icon: 'iconfont icon-shouye'
                }
            }
        ]
    }
];

export const notFoundAndNoPower = [
    {
        path: '/:path(.*)*',
        name: 'notFound',
        component: () => import('/@/views/error/404.vue'),
        meta: {
            title: 'message.staticRoutes.notFound',
            isHide: true
        }
    },
    {
        path: '/401',
        name: 'noPower',
        component: () => import('/@/views/error/401.vue'),
        meta: {
            title: 'message.staticRoutes.noPower',
            isHide: true
        }
    }
];

export const staticRoutes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: '/',
        component: () => import('/@/layout/index.vue'),
        meta: {
            title: '布局界面'
        },
        children: [
            // 请不要往这里 `children` 中添加内容，此内容为了防止 No match found for location with path "xxx" 问题
            ...notFoundAndNoPower
        ]
    },
    {
        path: '/login',
        name: 'login',
        component: () => import('/@/views/loginPage/loginPage.vue'),
        meta: {
            title: '登录'
        }
    },
    {
        path: '/newMenu',
        name: 'newMenu',
        component: () => import('/@/views/newHome/index.vue'),
        meta: {
            title: '首页',
            isKeepAlive: false
        }
    },
    {
        path: '/intelligentMap',
        name: 'intelligentMap',
        component: () => import('/@/views/intellectInspect/intelligentMap/index.vue'),
        meta: {
            title: '巡检路线'
        }
    },
    {
        path: '/intelligentLine',
        name: 'intelligentMap',
        component: () => import('/@/views/intellectInspect/intelligentLine/index.vue'),
        meta: {
            title: '巡检路线'
        }
    },
    {
        path: '/dpIndex',
        name: 'dpIndex',
        component: () => import('/@/views/doublePrevent/dpIndex/index.vue'),
        meta: {
            title: '双重预防首页'
        }
    },
    {
        path: '/warningScreen',
        name: 'warningScreen',
        component: () => import('/@/views/riskWarningSys/warningBigScreen/index.vue'),
        meta: {
            title: '预警预报'
        }
    },
    {
        path: '/screenPage',
        name: 'screenPage',
        component: () => import('/@/views/riskWarningSys/warningBigScreen/indexs/index.vue'),
        meta: {
            title: '预警预报'
        }
    },
    {
        path: '/msgDetail',
        name: 'msgDetail',
        component: () => import('/@/views/riskWarningSys/warningBigScreen/indexs/msgDetail.vue'),
        meta: {
            title: 'spi报告详情'
        }
    },
    {
        path: '/material',
        name: 'material',
        component: () => import('/@/views/specialWorkSystem/foundationSet/material/index.vue'),
        meta: {
            title: '作业物资'
        }
    }
];
